﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Windows.Forms;

namespace JPGs_to_AVI_2 {
	public partial class ConversionForm : Form {
		protected DirectoryInfo _sourceFolder;
		protected FileInfo _outputFile;
		protected int _framesPerImage;
		protected int _useEveryNthImage;
		protected bool _automated = false;
		protected bool _quitting = false;

		public ConversionForm(DirectoryInfo sourceFolder, FileInfo outputFile, int framesPerImage, int useEveryNthImage, bool automated) {
			InitializeComponent();

			_sourceFolder = sourceFolder;
			_outputFile = outputFile;
			_framesPerImage = framesPerImage;
			_useEveryNthImage = useEveryNthImage;
			_automated = automated;
		}

		private void ConversionForm_Shown(object sender, EventArgs e) {
			List<FileInfo> sortedImages = _sourceFolder.GetFiles("*.jpg").OrderBy(f => f.FullName).ToList();
			int numImages = sortedImages.Count();

			// setup progress bar
			progressBar1.Value = 0;
			progressBar1.Maximum = numImages * _framesPerImage / _useEveryNthImage;

			bool successful = false;
			DateTime start = DateTime.Now;

			AviWriter aviWriter = new AviWriter();
			try {
				Image firstJpg = Image.FromFile(sortedImages[0].FullName);
				Bitmap bmp = aviWriter.Open(_outputFile.FullName, 30, firstJpg.Width, firstJpg.Height);
				Graphics bmpGraphics = Graphics.FromImage(bmp);
				int fileNumber = 0;
				foreach (FileInfo fileInfo in sortedImages) {
					if (fileNumber % _useEveryNthImage == 0) { // skip some images
						Image jpg = Image.FromFile(fileInfo.FullName);
						jpg.RotateFlip(RotateFlipType.RotateNoneFlipY); // good grief!
						bmpGraphics.DrawImage(jpg, 0, 0, bmp.Width, bmp.Height);
						for (int i = 0; i < _framesPerImage; i++) {
							aviWriter.AddFrame();
							progressBar1.PerformStep();

							//update timer
							label_elapsed.Text = DateTime.Now.Subtract(start).ToString();
							double appxTicksPerFrame = (DateTime.Now.Ticks - start.Ticks) / progressBar1.Value;
							double appxTicksRemaining = (progressBar1.Maximum - progressBar1.Value) * appxTicksPerFrame;
							label_remaining.Text = new TimeSpan((long)appxTicksRemaining).ToString();
							Application.DoEvents();
							if (_quitting) break;
						}
					}
					fileNumber++;
					if (_quitting) break;
				}
				if (!_quitting) successful = true;

			} catch (AviWriter.AviException aviExc) {
				MessageBox.Show(aviExc.ToString());
			}
			aviWriter.Close();

			if (successful) {
				System.Diagnostics.Process.Start(_sourceFolder.Parent.FullName);
				if (!_automated) MessageBox.Show("Finished in " + DateTime.Now.Subtract(start).ToString());
			} else _outputFile.Delete();
			Hide();
		}

		private void ConversionForm_FormClosing(object sender, FormClosingEventArgs e) {
			if (e.CloseReason != CloseReason.UserClosing) return;

			if (MessageBox.Show("Are you sure you want to quit?", "Confirm", MessageBoxButtons.OKCancel) == DialogResult.OK)
				_quitting = true;
		}
	}
}
