﻿using System;
using System.IO;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Reflection;

namespace JPGs_to_AVI_2 {
	public partial class mainForm : Form {
		private int _numberJpgFiles = 0;
		protected Registry_Lib.RegLibrary _reg;
		protected bool _automated = false;

		public mainForm(string sourceFolder, int v)  {
			InitializeComponent();

			folderBrowserDialog1.SelectedPath = sourceFolder;
			UpdateDisplay(new DirectoryInfo(sourceFolder));
			trackBar1.Value = v;
			_automated = true;
		}
		public mainForm() {
			InitializeComponent();
		}

		private void mainForm_Load(object sender, EventArgs e) {
			if (!_automated) {
				_reg = new Registry_Lib.RegLibrary("Jarrin", "JPGs to AVI 2");

				string regDirectory = _reg.GetValueAsString("directory");
				if (regDirectory != "") {
					folderBrowserDialog1.SelectedPath = regDirectory;
					UpdateDisplay(new DirectoryInfo(regDirectory));
				}
			}
		}

		private void mainForm_Shown(object sender, EventArgs e) {
			if (_automated) { // begin conversion
				button_createAvi_Click(this, EventArgs.Empty);
			}
		}

		private void aboutToolStripMenuItem_Click(object sender, EventArgs e) {
			new About_Box.FormAbout().ShowDialog();
		}

		private void openFolderToolStripMenuItem_Click(object sender, EventArgs e) {
			if (folderBrowserDialog1.ShowDialog() != DialogResult.OK) return;
			UpdateDisplay(new DirectoryInfo(folderBrowserDialog1.SelectedPath));
		}

		protected void UpdateDisplay(DirectoryInfo sourceFolder) {
			label_sourceFolder.Text = sourceFolder.FullName;

			if (sourceFolder.Exists) {
				FileInfo[] allFiles = sourceFolder.GetFiles("*.jpg");
				long totalSize = 0;
				foreach (FileInfo fileInfo in allFiles) totalSize += fileInfo.Length;
				_numberJpgFiles = allFiles.Length;
				label_sourceSummary.Text = totalSize / (1024 * 1024) + "mb in " + _numberJpgFiles + " JPG files";
				label_outputFile.Text = GetOutputFilename();
				UpdateOutputSummary();
				button_createAvi.Enabled = (_numberJpgFiles > 0);

			} else {
				label_outputFile.Text = label_outputSummary.Text = label_sourceSummary.Text = "";
				button_createAvi.Enabled = false;
			}
		}

		private string GetOutputFilename() {
			string fnBase = label_sourceFolder.Text;

			if (!File.Exists(fnBase + ".avi")) return fnBase + ".avi";
			int n = 2;
			while (File.Exists(fnBase + "_" + n + ".avi")) n++;
			return fnBase + "_" + n + ".avi";
		}

		private void trackBar1_ValueChanged(object sender, EventArgs e) {
			UpdateOutputSummary();
		}

		protected void UpdateOutputSummary() {
			if (trackBar1.Value == 0) {
				int l = _numberJpgFiles / 30;
				label_outputSummary.Text = _numberJpgFiles + " images = " + l + " seconds";
			} else if (trackBar1.Value > 0) {
				int v = trackBar1.Value + 1; // a trackbar value of 0 is really 1 (and so on)
				int l = v * _numberJpgFiles / 30;
				label_outputSummary.Text = _numberJpgFiles + " images at " + v + " images per frame = " + l + " seconds";
			} else {
				int v = -1 * trackBar1.Value + 1; // a trackbar value of -1 is really "use every 2nd image" (and so on)
				int l = _numberJpgFiles / (30 * v);
				label_outputSummary.Text = _numberJpgFiles + " images, using every " + v + "th image = " + l + " seconds";
			}
		}

		private void trackBar1_MouseCaptureChanged(object sender, EventArgs e) {

		}

		private void mainForm_FormClosed(object sender, FormClosedEventArgs e) {
			if (_reg != null) {
				_reg.SetValue("directory", label_sourceFolder.Text);
				_reg.SaveKey();
			}
		}

		private void button_createAvi_Click(object sender, EventArgs e) {
			int framesPerImage = 1;
			int useEveryNth = 1;
			if (trackBar1.Value > 0) framesPerImage = trackBar1.Value + 1;
			else useEveryNth = -1 * trackBar1.Value + 1;

			ConversionForm cForm = new ConversionForm(new DirectoryInfo(label_sourceFolder.Text), new FileInfo(label_outputFile.Text), framesPerImage, useEveryNth, _automated);
			cForm.ShowDialog();
			if (_automated) Application.Exit();
		}

		private void mainForm_DragOver(object sender, DragEventArgs e) {
			if (e.Data.GetDataPresent(DataFormats.FileDrop)) e.Effect = DragDropEffects.Copy;
			else e.Effect = DragDropEffects.None;
		}

		private void mainForm_DragDrop(object sender, DragEventArgs e) {
			// try to catch when the eu drags a file or folder onto the form
			string[] draggedFiles = (string[])e.Data.GetData(DataFormats.FileDrop);

			if (Directory.Exists(draggedFiles[0])) { // dragging a directory
				label_sourceFolder.Text = draggedFiles[0];
			} else if (File.Exists(draggedFiles[0])) { // dragging a file
				label_sourceFolder.Text = new FileInfo(draggedFiles[0]).DirectoryName + @"\";
			}
			UpdateDisplay(new DirectoryInfo(label_sourceFolder.Text));
		}

	}
}
